"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const testUtils_1 = require("../testUtils");
const BtcMccConnection = {
    apiTokenKey: process.env.FLARE_API_PORTAL_KEY || "",
    url: process.env.BTC_URL || "",
    username: process.env.BTC_USERNAME || "",
    password: process.env.BTC_PASSWORD || "",
    rateLimitOptions: {
        timeoutMs: 15000,
    },
};
describe(`reference summaries, (${(0, testUtils_1.getTestFile)(__filename)})`, function () {
    let MccClient;
    describe(`BTC payment summary`, function () {
        let transaction;
        const txid = "ed30230596b7b801391b7b1f9aba414ac925a50a8dce32988ac075ccce746545";
        before(async function () {
            MccClient = new src_1.MCC.BTC(BtcMccConnection);
            transaction = await MccClient.getTransaction(txid);
        });
        it("Should be full transaction", async function () {
            (0, chai_1.expect)(transaction.type).to.eq("payment");
        });
        it("Should get summary", async function () {
            const summary = transaction.paymentNonexistenceSummary(0);
            (0, chai_1.expect)(summary.status).to.eq(src_1.PaymentNonexistenceSummaryStatus.Success);
            (0, chai_1.expect)(summary.response?.receivedAmount).to.eq(110252n);
            (0, chai_1.expect)(summary.response?.intendedReceivingAmount).to.eq(110252n);
            (0, chai_1.expect)(summary.response?.transactionStatus).to.eq(src_1.TransactionSuccessStatus.SUCCESS);
        });
        it("Should get invalid out utxo error", async function () {
            const error = transaction.paymentNonexistenceSummary(-1);
            (0, chai_1.expect)(error).to.deep.eq({
                status: src_1.PaymentNonexistenceSummaryStatus.InvalidOutUtxo,
            });
        });
    });
    describe(`BTC nonstandard output payment summary`, function () {
        let transaction;
        const txid = "c0b2cf75b47d1e7f48cdb4287109ff1dd5bcf146d5f77a9e8784c0c9c0ef02ad";
        before(async function () {
            MccClient = new src_1.MCC.BTC(BtcMccConnection);
            transaction = await MccClient.getTransaction(txid);
        });
        it("Should not construct summary", async function () {
            const summary = transaction.paymentNonexistenceSummary(0);
            (0, chai_1.expect)(summary.status).to.eq(src_1.PaymentNonexistenceSummaryStatus.NoReceiveAmountAddress);
        });
    });
    describe(`BTC nonstandard input payment summary`, function () {
        let transaction;
        const txid = "435fb30baf0d93712d021158636be1e1bc77c557e5b8e4c687741f8275687001";
        before(async function () {
            MccClient = new src_1.MCC.BTC(BtcMccConnection);
            transaction = await MccClient.getTransaction(txid);
        });
        it("Should not construct summary", async function () {
            const summary = transaction.paymentNonexistenceSummary(0);
            (0, chai_1.expect)(summary.status).to.eq(src_1.PaymentNonexistenceSummaryStatus.Success);
            (0, chai_1.expect)(summary.response?.receivedAmount).to.eq(479999n);
            (0, chai_1.expect)(summary.response?.receivingAddress).to.eq("1E9TG1fWGTABS82QMG4F8QuUZ2WVLDbEXy");
        });
    });
    describe("BTC summary coinbase ", function () {
        let transaction;
        const txid = "896081dd98965cb801dde02cf6981c65ff61b923c35fe9320944fd4546b7b5bd";
        before(async function () {
            transaction = await MccClient.getTransaction(txid);
        });
        it("Should be coinbase transaction", async function () {
            (0, chai_1.expect)(transaction.type).to.eq("coinbase");
        });
        it("Should get invalid in utxo error", async function () {
            const summary = transaction.paymentNonexistenceSummary(0);
            (0, chai_1.expect)(summary).to.deep.eq({
                status: src_1.PaymentNonexistenceSummaryStatus.Coinbase,
            });
        });
    });
});
//# sourceMappingURL=paymentNonexistence.test.js.map